@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2018-2022 Michael Samoglyadov
+# Copyright 2018-2023 Michael Samoglyadov
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,13 +16,11 @@
 
 """Recursive diff and patch for nested structures."""
 
-from warnings import warn
-
 import nested_diff.handlers
 
 __all__ = ['Differ', 'Iterator', 'Patcher', 'diff', 'patch']
 
-__version__ = '1.1'
+__version__ = '1.3.1'
 __author__ = 'Michael Samoglyadov'
 __license__ = 'Apache License, Version 2.0'
 __website__ = 'https://github.com/mr-mixas/Nested-Diff.py'
@@ -313,29 +311,23 @@ class Iterator():
             self._iters_by_ext[handler.extension_id] = handler.iterate_diff
 
 
-def diff(a, b, text_diff_ctx=-1, **kwargs):
+def diff(a, b, extra_handlers=(), **kwargs):
     """Calculate diff for two objects.
 
     Args:
         a: First object to diff.
         b: Second object to diff.
-        text_diff_ctx: Amount of context lines for text (multiline strings)
-            diffs. Disabled entirely when value is negative. This opt is
-            deprecated and should be avoided.
+        extra_handlers: List of additional type handlers.
         kwargs: Passed to Differ's constructor as is.
 
     Returns:
-        Tuple: equality flag and nested diff.
+        Tuple: nested diff.
 
     """
     differ = Differ(**kwargs)
 
-    if text_diff_ctx >= 0 and kwargs.get('N', True) and kwargs.get('O', True):
-        warn('`text_diff_ctx` opt is deprecated and will be removed soon',
-             DeprecationWarning, stacklevel=2)
-
-        differ.set_handler(nested_diff.handlers.TextHandler(
-            context=text_diff_ctx))
+    for handler in extra_handlers:
+        differ.set_handler(handler)
 
     return differ.diff(a, b)[1]
 
