@@ -62,7 +62,7 @@ class TypeHandler():
 
         return equal, diff
 
-    def patch(self, patcher, target, diff):
+    def patch(self, patcher, target, diff):  # noqa U100
         """Patch object.
 
         Args:
@@ -85,7 +85,7 @@ class TypeHandler():
 
         raise ValueError(diff)
 
-    def iterate_diff(self, iterator, diff):
+    def iterate_diff(self, iterator, diff):  # noqa U100
         """Iterate over nested diff.
 
         Args:
@@ -433,7 +433,7 @@ class ListHandler(TypeHandler):
 
         return target
 
-    def iterate_diff(self, iterator, diff):
+    def iterate_diff(self, iterator, diff):  # noqa U100
         """Iterate over nested diff.
 
         Args:
@@ -444,7 +444,7 @@ class ListHandler(TypeHandler):
             Tuples with diff, key and subdiff for each nested diff.
 
         """
-        idx = 0
+        idx = 0  # noqa SIM113
 
         for item in diff['D']:
             try:
@@ -458,7 +458,7 @@ class ListHandler(TypeHandler):
 
     def generate_formatted_diff(self, formatter, diff, depth):
         """Generate formatted list diff."""
-        idx = 0
+        idx = 0  # noqa SIM113
 
         for subdiff in diff['D']:
             try:
@@ -579,7 +579,7 @@ class SetHandler(TypeHandler):
 
         return equal, {}
 
-    def patch(self, patcher, target, diff):
+    def patch(self, patcher, target, diff):  # noqa U100
         """Patch set object.
 
         Args:
@@ -711,9 +711,9 @@ class TextHandler(TypeHandler):
         if diff:
             return equal, {'D': diff, 'E': self.extension_id}
 
-        return equal, {}
+        return equal, {'U': a} if differ.op_u else {}
 
-    def patch(self, patcher, target, diff):
+    def patch(self, patcher, target, diff):  # noqa U100
         """Patch text (multiline string).
 
         Unlike GNU patch, this algorithm does not implement any heuristics and
